==> mod_snmp-0.3.tar.gz: mod_snmp-0.3/src/mod_snmp.h <==
/*
**	mod_snmp.h	- Ember module for SNMP
**
**
** Copyright (c) 1997-2001  Hughes Technologies Pty Ltd.
**
** Permission to use, copy, and distribute for non-commercial purposes,
** is hereby granted without fee, providing that the above copyright
** notice appear in all copies and that both the copyright notice and this
** permission notice appear in supporting documentation.
**
** The software may be modified for your own purposes, but modified versions
** may not be distributed.
**
** This software is provided "as is" without any expressed or implied warranty.
**
*/




/*
** SNMP external function prototypes
*/

int doSnmpOpen();
int doSnmpClose();
int doSnmpGet();
int doSnmpGetNext();
int doSnmpSet();



/*
** Note : Dynamic loaded modules do not need to provide function
** pointers as the addresses of the module interface functions will
** be determined as it is loaded at run-time
*/

/*
** SNMP external function definitions
**
** This table maps from internal Lite function names to the C code.
** The format is :-
**
**	{LiteName, CFunctPtr, CFuntName, NumArgs, { Arg1Type, Arg2Type..., 0}}
**
**	Setting NumArgs to -1 indicates varargs
*/


static e_extern snmp_externs[] = {
	{ "snmpopen", doSnmpOpen, "_doSnmpOpen", 2, 
		{EMBER_TYPE_TEXT, EMBER_TYPE_TEXT, 0} },
	{ "snmpclose", doSnmpClose, "_doSnmpClose", 1, 
		{EMBER_TYPE_INT,  0} },
	{ "snmpget", doSnmpGet, "_doSnmpGet", 2, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, 0} },
	{ "snmpgetnext", doSnmpGetNext, "_doSnmpGetNext", 2, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, 0} },
	{ "snmpset", doSnmpSet, "_doSnmpSet", 3, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, EMBER_TYPE_ARRAY, 0} },

	{ NULL, 0 }
};

==> mod_snmp-1.0.tar.gz: mod_snmp-1.0/src/mod_snmp.h <==
/*
**	mod_snmp.h	- Ember module for SNMP
**
**
** Copyright (c) 1997-2001  Hughes Technologies Pty Ltd.
**
** Permission to use, copy, and distribute for non-commercial purposes,
** is hereby granted without fee, providing that the above copyright
** notice appear in all copies and that both the copyright notice and this
** permission notice appear in supporting documentation.
**
** The software may be modified for your own purposes, but modified versions
** may not be distributed.
**
** This software is provided "as is" without any expressed or implied warranty.
**
*/




/*
** SNMP external function prototypes
*/

int doSnmpOpen();
int doSnmpClose();
int doSnmpGet();
int doSnmpGetNext();
int doSnmpSet();
int doSnmpErrorCode();



/*
** Note : Dynamic loaded modules do not need to provide function
** pointers as the addresses of the module interface functions will
** be determined as it is loaded at run-time
*/

/*
** SNMP external function definitions
**
** This table maps from internal Ember function names to the C code.
** The format is :-
**
**	{EmberName, CFunctPtr, CFuntName, NumArgs, { Arg1Type, Arg2Type..., 0}}
**
**	Setting NumArgs to -1 indicates varargs
*/


static e_extern snmp_externs[] = {
	{ "snmpopen", doSnmpOpen, "_doSnmpOpen", 2, 
		{EMBER_TYPE_TEXT, EMBER_TYPE_TEXT, 0} },
	{ "snmpclose", doSnmpClose, "_doSnmpClose", 1, 
		{EMBER_TYPE_INT,  0} },
	{ "snmpget", doSnmpGet, "_doSnmpGet", 2, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, 0} },
	{ "snmpgetnext", doSnmpGetNext, "_doSnmpGetNext", 2, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, 0} },
	{ "snmpset", doSnmpSet, "_doSnmpSet", 3, 
		{EMBER_TYPE_INT, EMBER_TYPE_ARRAY, EMBER_TYPE_ARRAY, 0} },
	{ "snmperror", doSnmpErrorCode, "_doSnmpErrorCode", 0, 
		{0} },

	{ NULL, 0 }
};
